pub enum ApiRequestError {
UreqError {
source: Error,
location: Location,
uri: Uri,
},
MaxRetriesExceeded {
location: Location,
},
JsonParsingError {
source: Error,
data: String,
location: Location,
},
}Variants
Implementations
Sourceimpl ApiRequestError
impl ApiRequestError
Sourcepub fn is_retryable(&self) -> bool
pub fn is_retryable(&self) -> bool
Return true if the error is temporary and should be retried
Sourcepub fn is_timeout(&self) -> bool
pub fn is_timeout(&self) -> bool
Return true if the error is a timeout
Sourcepub fn is_connection_reset(&self) -> bool
pub fn is_connection_reset(&self) -> bool
Return true if the error is a connection reset
pub fn is_peer_disconnected(&self) -> bool